@@ -29,15 +29,13 @@ static void wm_sn_timeout_check (Wm *w);
 static void wm_sn_exec(Wm *w, char* name, char* bin_name, char *desc);
 
 static void wm_sn_monitor_event_func (SnMonitorEvent *event,
-				       void            *user_data);
+				      void           *user_data);
 
 static void wm_sn_cycle_update_root_prop(Wm *w);
 
 static SnCycle *wm_sn_cycle_new(Wm *w, const char *bin_name);
 
 static void wm_sn_cycle_add(Wm *w, const char *bin_name);
-
-
 #endif
 
 static Cursor blank_curs;
@@ -73,22 +71,16 @@ wm_new(int argc, char **argv)
                        |SubstructureNotifyMask
                        |StructureNotifyMask
                        |PropertyChangeMask;
-                       /* |KeymapStateMask; */
 
    /* Tell root win we wanna be wm */
 
    XChangeWindowAttributes(w->dpy, w->root, CWEventMask, &sattr);
 
 #if defined(USE_GCONF) || defined(USE_PANGO)
-
    g_type_init() ;
-
 #endif 
 
 #ifdef USE_GCONF
-
-   /* gconf_init(argc, argv, NULL); */
-
    w->gconf_client  = gconf_client_get_default();
    w->gconf_context = g_main_context_default ();
 
@@ -108,7 +100,6 @@ wm_new(int argc, char **argv)
 			       NULL);
      }
    else fprintf(stderr, "matchbox: failed to initialise gconf client\n");
-
 #endif
 
 #ifdef USE_XSETTINGS
@@ -139,13 +130,8 @@ wm_new(int argc, char **argv)
    ewmh_init(w);
 
 #ifdef USE_PANGO
-
    w->pgo = pango_xft_get_context (w->dpy, w->screen);
    w->pgo_fontmap = pango_xft_get_font_map (w->dpy, w->screen);
-
-   /* -- Needed ?
-   pango_context_set_language (w->pgo, pango_language_from_string ("ar_AE"));
-   */
 #endif
 
    comp_engine_init (w);
@@ -180,12 +166,10 @@ wm_new(int argc, char **argv)
 
    w->flags ^= STARTUP_FLAG; 	/* Remove startup flag */
 
-   /* XXX Temp XXX Remember to delete XXX Temp XXX */
-
-
    return w;
 }
 
+
 void
 wm_usage(char *progname)
 {
@@ -290,14 +274,15 @@ wm_usage(char *progname)
    exit(0);
 }
 
+
 void
 wm_load_config (Wm   *w, 
 		int  *argc, 
 		char *argv[])
 {
    static XrmDatabase rDB, cmdlnDB, srDB;
-   char *type;
-   XrmValue value;
+   char              *type;
+   XrmValue          value;
    
    static int opTableEntries = 8;
    static XrmOptionDescRec opTable[] = {
@@ -308,9 +293,6 @@ wm_load_config (Wm   *w,
       {"-use_lowlight",    ".lowlight",    XrmoptionSepArg, (XPointer) NULL},
       {"-use_dialog_mode", ".dialog",      XrmoptionSepArg, (XPointer) NULL},
       {"-use_desktop_mode",".desktop",     XrmoptionSepArg, (XPointer) NULL},
-      /*
-      {"-ping_handler",    ".pinghandler",     XrmoptionSepArg, (XPointer) NULL},
-      */
       {"-titlebar_panel",  ".titlebarpanel", XrmoptionSepArg, (XPointer) NULL},
    };
    
@@ -396,7 +378,7 @@ wm_load_config (Wm   *w,
      }   
 
    /* 
-    *  Composite matchbox always uses lowlighting ... 
+    *  Composite matchbox always uses lowlighting 
     */
 #ifndef USE_COMPOSITE
    if (XrmGetResource (rDB, "matchbox.lowlight", "Matchbox.Lowlight",
@@ -443,17 +425,6 @@ wm_load_config (Wm   *w,
 	 }
      } 
 
-   /*
-   if (XrmGetResource(rDB, "matchbox.pinghandler", "Matchbox.Pinghandler",
-		      &type, &value) == True)
-   {
-     w->config->ping_handler = (char *)malloc(sizeof(char)*(value.size+1));
-     strncpy(w->config->ping_handler, value.addr, (int) value.size);
-     w->config->ping_handler[value.size] = '\0';
-     dbg("%s() got ping handler :%s ", __func__, w->config->ping_handler);
-   }
-   */
-
 #ifdef STANDALONE
    if (XrmGetResource(rDB, "matchbox.titlebarpanel", "Matchbox.Titlebarpanel",
 		      &type, &value) == True)
@@ -478,9 +449,13 @@ wm_load_config (Wm   *w,
    }
 #endif
 
-
+   if (getenv("MB_AWT_WORKAROUND"))
+     w->config->awt_workaround = True;
+   else
+     w->config->awt_workaround = False;
 }
 
+
 void
 wm_init_existing(Wm *w)
 {
@@ -503,10 +478,9 @@ wm_init_existing(Wm *w)
       }
    }
    XFree(wins);
- 
-   // comp_engine_render(w, None);
 }
 
+
 Client*
 wm_find_client(Wm *w, Window win, int mode)
 {
@@ -525,10 +499,12 @@ wm_find_client(Wm *w, Window win, int mode)
     return NULL;
 }
 
-static Bool
-get_xevent_timed(Display* dpy, XEvent* event_return, struct timeval *tv)
-{
 
+static Bool
+get_xevent_timed(Display        *dpy, 
+		 XEvent         *event_return, 
+		 struct timeval *tv)
+{
   if (tv->tv_usec == 0 && tv->tv_sec == 0)
     {
       XNextEvent(dpy, event_return);
@@ -557,12 +533,12 @@ get_xevent_timed(Display* dpy, XEvent* event_return, struct timeval *tv)
     }
 }
 
+
 #ifdef USE_COMPOSITE
 
 /*  For the compositing engine we need to track overide redirect  
  *  windows. 
  */
-
 void 
 wm_handle_map_notify(Wm *w, Window win)
 {
@@ -634,9 +610,9 @@ wm_handle_map_notify(Wm *w, Window win)
     }
 
 }
-
 #endif
 
+
 void
 wm_event_loop(Wm* w)
 {
@@ -753,8 +729,6 @@ wm_event_loop(Wm* w)
    
       }
 
-      //    } while (XEventsQueued (w->dpy, QueuedAfterReading));
-
 #ifdef USE_COMPOSITE
       if (w->all_damage)
       	{
@@ -773,15 +747,14 @@ wm_handle_button_event(Wm *w, XButtonEvent *e)
    Client *p;
    Client *c = wm_find_client(w, e->window, WINDOW);
 
+   /* raise dialogs */
+   if (c && c->type == dialog) 
+     c->show(c);
+
    XAllowEvents(w->dpy, ReplayPointer, CurrentTime);
 
    if (c && c->type != menu && c->type != dock && client_want_focus(c))
      {
-       /* XXX
-        *  o This needs work .. should work for desktop type too 
-        *  o check for _NET_WM_STATE_MODAL - set modal flag ?
-        *  o test test test ...
-        */
        XSetInputFocus(c->wm->dpy, c->window,
 		      RevertToPointerRoot, CurrentTime);
        c->wm->focused_client = c;
@@ -790,7 +763,7 @@ wm_handle_button_event(Wm *w, XButtonEvent *e)
 
    c = wm_find_client(w, e->window, FRAME);
 
-   /* find out if this is a double click */
+   /* find out if this is a double click - FIXME not used */
    if (w->next_click_is_not_double) {
       w->last_click_window = e->window;
       w->last_click_time   = e->time;
@@ -832,6 +805,7 @@ wm_handle_button_event(Wm *w, XButtonEvent *e)
    if (w->flags & DBL_CLICK_FLAG) w->flags ^= DBL_CLICK_FLAG;
 }
 
+
 void
 wm_handle_keypress(Wm *w, XKeyEvent *e)
 {
@@ -968,6 +942,7 @@ wm_handle_keypress(Wm *w, XKeyEvent *e)
 #endif
 }
 
+
 void
 wm_handle_configure_notify(Wm *w, XConfigureEvent *e)
 {
@@ -1093,14 +1068,16 @@ wm_handle_configure_notify(Wm *w, XConfigureEvent *e)
    }
 }
 
+
 void
 wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
 {
    Client         *c = wm_find_client(w, e->window, WINDOW);
    XWindowChanges  xwc;
    Bool            need_comp_update = False;
+   Bool            no_configure     = False;
 
-   if (!c) 
+   if (!c ) 
      {
        dbg("%s() could find source client\n", __func__ );
        xwc.x = e->x;
@@ -1110,10 +1087,11 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
        xwc.sibling = e->above;
        xwc.stack_mode = e->detail;
        XConfigureWindow(w->dpy, e->window, e->value_mask, &xwc);
+
        return;
      }
    
-   dbg("%s() for win %s - have x: %i vs %i, y: %i vs %i, w: %i vs %i, h: %i vs %i,\n", __func__, c->name, c->height, e->height, c->width, e->width, c->x, e->x, c->y, e->y );
+   dbg("%s() for win %s - have w: %i vs %i, h: %i vs %i, x: %i vs %i, y: %i vs %i,\n", __func__, c->name, c->height, e->height, c->width, e->width, c->x, e->x, c->y, e->y );
    
    if (c->type == dock) 	/* Docks can move */
      {
@@ -1144,36 +1122,114 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
         } 
        return;
      } 
-   
-   /* allow decoration free dialogs to move themselves */
-   if (c->type == dialog  	
-       && ( c->flags & CLIENT_TITLE_HIDDEN_FLAG 
-	    || c->wm->config->dialog_stratergy == WM_DIALOGS_STRATERGY_FREE)
-       )
+
+   if (c->type == toolbar) 	/* can change height */
      {
-       c->width  = xwc.width  = e->width;
-       c->height = xwc.height = e->height;
-       c->x      = xwc.x = e->x;
-       c->y      = xwc.y = e->y;
-
-       /* Make sure we get the damage before the move.. */
-       comp_engine_client_show(c->wm, c); 
-
-       need_comp_update = True;
-       
-     } else {
-       xwc.width  = c->width;
-       xwc.height = c->height;
-       xwc.x = c->x;
-       xwc.y = c->y;
+       if ((e->value_mask & CWHeight) && e->height 
+	   && e->height != c->height && !(c->flags & CLIENT_IS_MINIMIZED))
+	 {
+	   int change_amount = c->height - e->height;
+	   
+	   c->height = e->height;
+	   c->move_resize(c);
+	   wm_restack(w, c, change_amount); 
+	   return;
+	 }
      }
-   
+
+   xwc.width  = c->width;
+   xwc.height = c->height;
+   xwc.x = c->x;
+   xwc.y = c->y;
+
+   if (c->type == dialog)
+     {
+       int req_x = e->x, req_y = e->y, req_w = e->width, req_h = e->height;
+
+       /* Process exactly what changes have been reuested */
+       if (!(e->value_mask & CWWidth))  req_w = c->width;
+       if (!(e->value_mask & CWHeight)) req_h = c->height;
+
+       if (e->x <= 0 || !(e->value_mask & CWX)) req_x = c->x;
+       if (e->y <= 0 || !(e->value_mask & CWY)) req_y = c->y;
+
+       /* Update the size the dialog is trying to get too eventually
+        * - eg toolbar/panel/input windows may dissapear and make
+        *      more space available. 
+        */
+       if (e->width && (e->value_mask & CWWidth) 
+	   && e->width != c->width && e->width != c->init_width)
+	 c->init_width = e->width;
+
+       if (e->height && (e->value_mask & CWHeight) 
+	   && e->height != c->height && e->height != c->init_height)
+	 c->init_height = e->height;
+
+       /* If any changes, now make them fit it into avaialable area. */
+       if (req_x != c->x || req_y != c->y 
+	   || req_w != c->width || req_h != c->height)
+	 {
+	   dialog_check_geometry(c, &req_x, &req_y, &req_w, &req_h);
+
+	   /* make sure buttons get repositioned */
+	   if (c->width != req_w)
+	     client_buttons_delete_all(c);
+
+	   comp_engine_client_hide(c->wm, c);
+#ifdef USE_COMPOSITE
+	   XSync(w->dpy, False);
+#endif
+	   xwc.width  = c->width  = req_w;
+	   xwc.height = c->height = req_h;
+	   xwc.x      = c->x      = req_x;
+	   xwc.y      = c->y      = req_y; 
+
+	   /* for below */
+	   no_configure = True; 
+
+	   dialog_client_move_resize(c);
+
+	   client_deliver_config(c);
+
+	   /* Make sure we get the damage before the move.. */
+
+	   need_comp_update = True;
+	 }
+     }
+
    xwc.border_width = 0;
    xwc.sibling = e->above;
    xwc.stack_mode = e->detail;
-   
-   XConfigureWindow(w->dpy, e->window,
-		    e->value_mask, &xwc);
+
+   if (!no_configure) 
+     {
+
+       /* 
+        * For some reason awt ( kaffe ) apps dont like getting anything
+        * other than what they've asked for in there *first* configure_request
+        * response ( they dont paint there UI otherwise ).
+        * This is a quick fix which sends 2 configure differering events  
+        * which seems to make things better. Im not sure what the best fix is. 
+        *
+        * Set MB_AWT_WORKAROUND env var to enable this. 
+        *
+        */
+
+       if (w->config->awt_workaround)
+	 {
+	   xwc.width  = e->width;
+	   xwc.height = e->height;
+
+	   XConfigureWindow(w->dpy, e->window, e->value_mask, &xwc);
+
+	   xwc.width  = c->width;
+	   xwc.height = c->height;
+
+	 }
+
+       XConfigureWindow(w->dpy, e->window, e->value_mask, &xwc);
+
+     }
 
    /* XXX Only raise a client if it size is constant and above is set 
       This may be broken                                             */
@@ -1193,11 +1249,15 @@ wm_handle_configure_request (Wm *w, XConfigureRequestEvent *e )
 	 }
      }
 
-   /* A bit hacky */
+   /* make sure composite does any needed updates */
    if (need_comp_update == True)
-     comp_engine_client_show(c->wm, c); 
+     {
+       comp_engine_client_configure(w, c);
+       comp_engine_client_show(w, c);
+     }
 }
 
+
 void
 wm_handle_map_request(Wm *w, XMapRequestEvent *e)
 {
@@ -1211,6 +1271,7 @@ wm_handle_map_request(Wm *w, XMapRequestEvent *e)
    }
 }
 
+
 void
 wm_handle_unmap_event(Wm *w, XUnmapEvent *e)
 {
@@ -1241,6 +1302,7 @@ wm_handle_unmap_event(Wm *w, XUnmapEvent *e)
      }
 }
 
+
 void
 wm_handle_expose_event(Wm *w, XExposeEvent *e)
 {
@@ -1259,6 +1321,7 @@ wm_handle_expose_event(Wm *w, XExposeEvent *e)
    }
 }
 
+
 void
 wm_handle_destroy_event(Wm *w, XDestroyWindowEvent *e)
 {
@@ -1270,6 +1333,7 @@ wm_handle_destroy_event(Wm *w, XDestroyWindowEvent *e)
     wm_remove_client(w, c);
 }
 
+
 void
 wm_handle_client_message(Wm *w, XClientMessageEvent *e)
 {
@@ -1339,7 +1403,11 @@ wm_handle_client_message(Wm *w, XClientMessageEvent *e)
 	   wm_toggle_desktop(w);
 	   break;
 	 case MB_CMD_MISC: 	/* This is used for random testing stuff */
-	   comp_engine_time(w);
+#ifdef DEBUG
+	   /* comp_engine_time(w); Not used atm XXX DO_TIMINGS */
+	   dbg("*** Toggling composite visual debugging ***\n");
+	   w->flags ^= DEBUG_COMPOSITE_VISIBLE_FLAG;
+#endif
 	   break;
 	 }
        return;
@@ -1358,6 +1426,7 @@ wm_handle_client_message(Wm *w, XClientMessageEvent *e)
    ewmh_handle_root_message(w, e);   
 }
 
+
 void
 wm_handle_property_change(Wm *w, XPropertyEvent *e)
 {
@@ -1366,6 +1435,7 @@ wm_handle_property_change(Wm *w, XPropertyEvent *e)
   Client *c = wm_find_client(w, e->window, WINDOW);
 
   if (!c) return; 
+
   if (c->type == MBCLIENT_TYPE_OVERRIDE) return;
 
   dbg("%s() on %s, atom is %li\n", __func__, c->name, e->atom );
@@ -1378,6 +1448,11 @@ wm_handle_property_change(Wm *w, XPropertyEvent *e)
       dbg("%s() XA_WM_NAME change, name is %s\n", __func__, c->name);
       update_titlebar = True;
     }
+  else if (e->atom == w->atoms[MB_WIN_SUB_NAME])
+    {
+      ewmh_get_utf8_prop(w, c->window, w->atoms[MB_WIN_SUB_NAME]);
+      update_titlebar = True;
+    }
   else if (e->atom == w->atoms[_NET_WM_NAME])
     {
       if (c->name) XFree(c->name);
@@ -1408,20 +1483,17 @@ wm_handle_property_change(Wm *w, XPropertyEvent *e)
   if (update_titlebar)  c->redraw(c, False);
 }
 
+
 Client*
 wm_make_new_client(Wm *w, Window win)
 {
-   Window trans_win;
-   Atom realType;
-   unsigned long n;
-   unsigned long extra;
-   unsigned long  val[1];
-   int format;
-   int status;
-   Atom *value = NULL;
-   Client *c = NULL, *t = NULL, *old_main_client = NULL;
-   XWMHints *wmhints;
-   int mwm_flags = 0;
+   Window        trans_win;
+   Atom          realType, *value = NULL;;
+   unsigned long n, extra, val[1];
+   int           format, status;
+   Client       *c = NULL, *t = NULL, *old_main_client = NULL;
+   XWMHints     *wmhints;
+   int           mwm_flags = 0;
 
    XGrabServer(w->dpy);
 
@@ -1444,7 +1516,8 @@ wm_make_new_client(Wm *w, Window win)
 	       c = dockbar_client_new(w, win);
 	       if (c == NULL) goto end;
 	     }
-	   else if (value[0] == w->atoms[WINDOW_TYPE_TOOLBAR])
+	   else if (value[0] == w->atoms[WINDOW_TYPE_TOOLBAR]
+		    || value[0] == w->atoms[WINDOW_TYPE_INPUT])
 	     {
 	       dbg("%s() got toolbar atom\n", __func__ );
 	       c = toolbar_client_new(w, win);
@@ -1470,9 +1543,7 @@ wm_make_new_client(Wm *w, Window win)
 	       c = dialog_client_new(w, win, NULL);
 	       if (c == NULL) goto end;
 	     }
-
 #ifdef USE_MSG_WIN
-	   
 	   else if (value[0] == w->atoms[WINDOW_TYPE_MESSAGE])
 	     {
 
@@ -1514,7 +1585,6 @@ wm_make_new_client(Wm *w, Window win)
 		   if (c == NULL) goto end;
 		   c->flags ^= CLIENT_IS_MESSAGE_DIALOG|CLIENT_IS_MESSAGE_DIALOG_LO; 
 	     }
-
 #endif
 	   
 	 } 
@@ -1620,6 +1690,8 @@ wm_make_new_client(Wm *w, Window win)
    
    c->configure(c);
 
+   comp_engine_client_init(w, c);
+
    dbg("%s() reparenting new client\n", __func__ );
    
    c->reparent(c);
@@ -1628,8 +1700,6 @@ wm_make_new_client(Wm *w, Window win)
    
    c->move_resize(c);
 
-   comp_engine_client_init(w, c);
-
    dbg("%s() showing new client\n", __func__);
 
    c->show(c);
@@ -1657,31 +1727,33 @@ wm_make_new_client(Wm *w, Window win)
    return c;
 }
 
+
 void
 wm_remove_client(Wm *w, Client *c)
 {
   dbg("%s() called for %s\n", __func__, c->name);
 
   XGrabServer(c->wm->dpy);
-
   XSetErrorHandler(ignore_xerror);
-
   c->destroy(c);
-
   XSetErrorHandler(handle_xerror);
-
   XUngrabServer(w->dpy);
 }
 
 
 void
-wm_restack(Wm *w, Client *client_changed, signed int change_amount)
+wm_restack(Wm         *w, 
+	   Client     *client_changed, 
+	   signed int  change_amount)
 {
  Client *p;
-
  XGrabServer(w->dpy);
- for (p=client_changed->next; p != client_changed; p=p->next)
+
+ for (p=client_changed->next; p != client_changed; p=p->next) 
    {
+     if (p == client_changed)
+       continue;
+
      dbg("%s() restacking, comparing %i is less than %i for %s\n",
 	 __func__, p->y, client_changed->y, p->name);
      if (client_changed->type == dock 
@@ -1825,7 +1897,7 @@ wm_restack(Wm *w, Client *client_changed, signed int change_amount)
 	     switch (p->type)
 	       {
 	       case mainwin :
-		 if (p->flags & CLIENT_FULLSCREEN_FLAG) break;
+		 /* if (p->flags & CLIENT_FULLSCREEN_FLAG) break; */
 		 p->height += change_amount;
 		 p->move_resize(p);
 		 theme_img_cache_clear( w->mbtheme, FRAME_MAIN );
@@ -1846,13 +1918,14 @@ wm_restack(Wm *w, Client *client_changed, signed int change_amount)
 		   }
 		 break;
 	       case dialog :
-
+		 /*
 		 if (p->flags & CLIENT_SHRUNK_FOR_TB_FLAG)
 		   {
 		     p->height += change_amount;
 		     p->move_resize(p);
 		     client_deliver_config(p);
 		   }
+		 */
 	       default:
 		 break;
 	       }
@@ -1860,12 +1933,31 @@ wm_restack(Wm *w, Client *client_changed, signed int change_amount)
       }
    }
 
+
+ /* Handle dialogs */
+ START_CLIENT_LOOP(w, p)
+   {
+     if (p->type == dialog) 
+       {
+	 int req_x = p->x, req_y = p->y, req_w = p->width, req_h = p->height;
+
+	 if (!dialog_check_geometry(p, &req_x, &req_y, &req_w, &req_h))
+	   {
+	     p->x = req_x; p->y = req_y; p->width = req_w; p->height = req_h;
+	     p->move_resize(p);
+	     client_deliver_config(p);
+	   }
+       }
+   }
+ END_CLIENT_LOOP(w, p);
+
  XSync(w->dpy, False);
  XUngrabServer(w->dpy);
 
  ewmh_update_rects(w);
 }
 
+
 void 
 wm_activate_client(Client *c)
 {
@@ -1886,7 +1978,8 @@ wm_activate_client(Client *c)
   ewmh_set_active(c->wm);
 }
 
-Client * 			/* Returns either desktop or main app client */
+
+Client*   /* Returns either desktop or main app client */
 wm_get_visible_main_client(Wm *w)
 {
   if (w->flags & DESKTOP_RAISED_FLAG)
@@ -1897,6 +1990,7 @@ wm_get_visible_main_client(Wm *w)
   return NULL;
 }
 
+
 int
 wm_get_offsets_size(Wm*     w, 
 		    int     wanted_direction,
@@ -1914,7 +2008,8 @@ wm_get_offsets_size(Wm*     w,
 
    START_CLIENT_LOOP(w, p)
      {
-       if (ignore_client && p == ignore_client) continue;
+       if ((ignore_client && p == ignore_client) || p->mapped == False) 
+	 continue;
 
        switch(wanted_direction)
 	 {
@@ -1954,6 +2049,7 @@ wm_get_offsets_size(Wm*     w,
    return result;
 }
 
+
 void
 wm_toggle_desktop(Wm *w)
 {
@@ -1985,6 +2081,10 @@ wm_toggle_desktop(Wm *w)
 
 	   wm_activate_client(wm_get_desktop(w));
 	   w->flags ^= DESKTOP_RAISED_FLAG;
+
+	   if (w->have_titlebar_panel 
+	       && mbtheme_has_titlebar_panel(w->mbtheme))
+	     XMapRaised(w->dpy, w->have_titlebar_panel->frame);
 	 }
        return;
      }
@@ -2047,10 +2147,13 @@ wm_toggle_desktop(Wm *w)
 	w->flags ^= DESKTOP_RAISED_FLAG;	
    }
 
-   ewmh_update(w);
-   ewmh_set_active(w);
 
    XUngrabServer(w->dpy);
+
+   XSync(w->dpy, False);
+
+   ewmh_update(w);
+   ewmh_set_active(w);
 }
 
 void
@@ -2159,14 +2262,6 @@ wm_xsettings_notify_cb (const char       *name,
 	  else
 	      mbtheme_switch(w, setting->data.v_string);
 	  break;
-	  /*
-	case XSET_LOWLIGHT:
-	  if (!strcasecmp("true", setting->data.v_string))
-	      w->config->dialog_shade = True;
-	  else
-	      w->config->dialog_shade = False;
-	  break;
-	  */
 	case XSET_CURSOR:
 	  if (!strcasecmp("true", setting->data.v_string))
 	    wm_set_cursor_visibility(w, True);
@@ -2216,11 +2311,10 @@ wm_sn_exec(Wm *w, char* name, char* bin_name, char *desc)
       _exit (1);
       break;
     }
-  //wm_sn_cycle_add(w, bin_name);
   sn_launcher_context_unref (context);
-
 }
 
+
 static void 
 wm_sn_timeout_check (Wm *w)
 {
@@ -2246,6 +2340,7 @@ wm_sn_timeout_check (Wm *w)
     }
 }
 
+
 static void 
 wm_sn_cycle_update_root_prop(Wm *w)
 {
@@ -2316,6 +2411,7 @@ wm_sn_cycle_update_root_prop(Wm *w)
   XUngrabServer(w->dpy);
 }
 
+
 static SnCycle * 
 wm_sn_cycle_new(Wm *w, const char *bin_name)
 {
@@ -2327,6 +2423,7 @@ wm_sn_cycle_new(Wm *w, const char *bin_name)
   return new_cycle;
 }
 
+
 static void 
 wm_sn_cycle_add(Wm *w, const char *bin_name)
 {
@@ -2361,6 +2458,7 @@ wm_sn_cycle_add(Wm *w, const char *bin_name)
   wm_sn_cycle_update_root_prop(w);
 }
 
+
 void
 wm_sn_cycle_remove(Wm *w, Window xid)
 {
@@ -2425,7 +2523,6 @@ static void
 wm_sn_monitor_event_func (SnMonitorEvent *event,
 			  void            *user_data)
 {
-  /* SnMonitorContext *context; */
   SnStartupSequence *sequence;
   Wm *w = (Wm *)user_data;
   const char *seq_id = NULL, *bin_name = NULL;
@@ -2433,10 +2530,9 @@ wm_sn_monitor_event_func (SnMonitorEvent *event,
 
   dbg("%s() called\n", __func__);
 
-  /* context = sn_monitor_event_get_context (event); */
   sequence = sn_monitor_event_get_startup_sequence (event);
 
-  if (/* context == NULL || */ sequence == NULL)
+  if (sequence == NULL)
     {
       dbg("%s() failed, context / sequence is NULL\n", __func__);
       return;
@@ -2618,8 +2714,6 @@ wm_msg_win_queue_add(Wm *w, Window win)
   
   dbg("%s() queue has items, adding to back \n", __func__);
 
-
-
   while (tmp->next != NULL) tmp = tmp->next;
 
   tmp->next = malloc(sizeof(MsgWinQueue));
@@ -2628,6 +2722,7 @@ wm_msg_win_queue_add(Wm *w, Window win)
   tmp->next->timeout = timeout;
 }
 
+
 void
 wm_msg_win_queue_pop(Wm *w)
 {
@@ -2657,6 +2752,7 @@ wm_msg_win_queue_pop(Wm *w)
     }
 }
 
+
 void
 wm_msg_win_queue_process(Wm *w)
 {
@@ -2677,11 +2773,9 @@ wm_msg_win_queue_process(Wm *w)
 	wm_remove_client(w, client_msg);
       }
 }
-
 #endif
 
 #ifdef USE_GCONF
-
 void
 gconf_key_changed_callback (GConfClient *client,
 			    guint        cnxn_id,
@@ -2752,32 +2846,6 @@ gconf_key_changed_callback (GConfClient *client,
 	  dbg("%s() value is useless to me...\n", __func__ );
 	}
     } 
-
-  /* XX no free */
-  /*
-  value = GConfValue *gconf_entry_get_value (const GConfEntry *entry);
-  const char* gconf_entry_get_key (const GConfEntry *entry);
-
-  value->type
-
-    typedef enum {
-      GCONF_VALUE_INVALID,
-      GCONF_VALUE_STRING,
-      GCONF_VALUE_INT,
-      GCONF_VALUE_FLOAT,
-      GCONF_VALUE_BOOL,
-      GCONF_VALUE_SCHEMA,
-      GCONF_VALUE_LIST,
-      GCONF_VALUE_PAIR
-  
-    } GConfValueType;
-  */
-  /* dont free */
-  /*
-  const char* gconf_value_get_string          (const GConfValue *value);
-  int         gconf_value_get_int             (const GConfValue *value);
-  gboolean    gconf_value_get_bool            (const GConfValue *value);
-  */
 }
 
 #endif
